using System;

namespace ESRI.BAServer.SOAP
{
	/// <summary>
	/// This provider requests a new token using HTTPS SSL connection and user credentials
	/// saved in the private instance members.
	/// </summary>
	public class HTTPTokenProvider : TokenProvider
	{
		string tokenServiceUrl;
		string username;
		string password;
		string format = "request=getToken&username={0}&password={1}";

		/// <summary>
		/// Initializes a new instance of the <see cref="HTTPTokenProvider"/> class.
		/// </summary>
		/// <param name="tokenServiceUrl">Token service URL.</param>
		/// <param name="username">User name.</param>
		/// <param name="password">Password.</param>
		public HTTPTokenProvider(string tokenServiceUrl, string username, string password)
		{
			this.tokenServiceUrl = tokenServiceUrl;
			this.username = username;
			this.password = password;
		}

		/// <summary>
		/// Gets or sets the query format string.
		/// </summary>
		/// <remarks>
		/// <para>The default query format is "request=getToken&amp;username={0}&amp;password={1}".</para>
		/// <para>You can modify this format in order to obtain a long-lived token. For example,
		/// <code>
		/// HTTPTokenProvider tokenProvider = new HTTPTokenProvider(tokenServiceUrl, username, password);
		/// tokenProvider.QueryFormat = "request=getToken&amp;clientid=ip.10.212.22.244&amp;expiration=1440&amp;" +
		///     "username={0}&amp;password={1}";
		/// </code>
		/// </para>
		/// </remarks>
		public string QueryFormat
		{
			get { return format; }
			set { format = value; }
		}

		/// <summary>
		/// Creates a new token.
		/// </summary>
		public override void UpdateToken()
		{
			CurrentToken = GetToken(tokenServiceUrl, string.Format(format, username, password));
		}
	}
}
